
    const literacy = require('./index');



    const argv = require('yargs')
      .usage(
        '\n' +
        'Literate programming in JavaScript using reStructured Text. This ' +
        'command extracts code blocks from `.js.rst` and `.json.rst` ' +
        'reStructured Text files.\n' +
        '\n' +
        'Usage: $0 [options] <paths>'
      )


      .demandCommand(1)


      .describe('out-file', 'Compile to an output file')
      .string('out-file')
      .alias('o', 'out-file')


      .describe('out-dir', 'Compile to an output directory')
      .string('out-dir')
      .alias('d', 'out-dir')


      .describe('copy-files', 'Copy unprocessed files to output directory')
      .boolean('copy-files')
      .alias('D', 'copy-files')


      .describe('source-maps', 'Generate source maps for output files')
      .boolean('source-maps')
      .alias('s', 'source-maps')


      .describe('quiet', 'Suppress messages')
      .boolean('quiet')
      .alias('q', 'quiet')


      .help()
      .alias('h', 'help')

      .version()
      .alias('v', 'version')


      .argv;


    const utils = require('./utils');
    const inputs = utils.expand(argv._);



    const errors = [];

    const outFileFlagPresent = typeof argv.outFile !== 'undefined';
    const outDirFlagPresent = typeof argv.outDir !== 'undefined';

    if (outFileFlagPresent && outDirFlagPresent) {
      errors.push('Cannot have --out-file and --out-dir.');
    }


    if (!outFileFlagPresent && !outDirFlagPresent) {
      errors.push('Must have either --out-file or --out-dir.');
    }


    if (argv.copyFiles && !outDirFlagPresent) {
      errors.push('--copy-files requires --out-dir.');
    }


    const fs = require('fs-extra');

    inputs.forEach(input => {
      if (!fs.existsSync(input)) {
        errors.push(`${ input } not found.`);
      }
    });


    if (outFileFlagPresent) {
      if (inputs.length !== 1) {
        errors.push('Must have exactly one input file for --out-file.');
      } else if (fs.statSync(inputs[0]).isDirectory()) {
        errors.push('Input file cannot be a directory for --out-file.');
      } else if (!inputs[0].endsWith('.js.rst') && !inputs[0].endsWith('.json.rst')) {
        errors.push('Input file must be `.js.rst` or `.json.rst` for --out-file.');
      }
    }


    if (errors.length > 0) {
      console.error(`ERROR: ${ errors[0] }`);
      process.exit(1);
    }



    function transpileRstFile(inputFile, outputFile) {
      try {
        const output = literacy.fromFile(inputFile);

        fs.ensureFileSync(outputFile);
        fs.writeFileSync(outputFile, output.content);
        if (!argv.quiet) {
          console.log(`Output written to ${ outputFile }.`);
        }

        if (argv.sourceMaps) {
          fs.writeFileSync(`${ outputFile }.map`, output.sourceMap);
          console.log(`Source map written to ${ outputFile }.map.`);
        }
      } catch (error) {
        console.log(error);
      }
    }

    if (outFileFlagPresent) {
      transpileRstFile(inputs[0], argv.outFile);
    }



    const path = require('path');

    function transpileFile(inputFile, relativeOutputFile) {
      try {


        let outputFile = path.join(argv.outDir, relativeOutputFile);

        if (inputFile.endsWith('.js.rst') || inputFile.endsWith('json.rst')) {
          outputFile = outputFile.slice(0, -4);
          transpileRstFile(inputFile, outputFile);


        } else if (argv.copyFiles) {
          fs.ensureFileSync(outputFile);
          fs.copySync(inputFile, outputFile);

          if (!argv.quiet) {
            console.log(`Output written to ${ outputFile }.`);
          }
        } else if (!argv.quiet) {
          console.log(`Skipped ${ inputFile }.`);
        }
      } catch (error) {
        console.log(error);
      }
    }


    if (outDirFlagPresent) {
      inputs.forEach(input => {


        if (fs.statSync(input).isDirectory()) {
          const filenames = utils.recursivelyEnumerate(input);

          filenames.forEach(filename => {
            transpileFile(filename, path.relative(input, filename));
          });


        } else {
          transpileFile(input, path.basename(input));
        }
      });
    }

